<?php
require_once __DIR__ . '/../db.php';

if (!isset($_GET['id'])) {
    header("Location: ver_certificados.php");
    exit();
}

$id = intval($_GET['id']);

// Obtener datos actuales
$stmt = $pdo->prepare("SELECT * FROM certificados WHERE id = ?");
$stmt->execute([$id]);
$certificado = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$certificado) {
    die("Certificado no encontrado.");
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $cedula   = trim($_POST['cedula']);
    $nombre   = trim($_POST['nombre_participante']);
    $curso    = trim($_POST['nombre_curso']);
    $registro = trim($_POST['numero_registro']);
    $fecha    = $_POST['fecha_realizacion'];

    // Ruta actual en BD
    $ruta_archivo = $certificado['archivo_certificado'];

    // Si se sube un nuevo PDF
    if (!empty($_FILES['archivo']['name']) && $_FILES['archivo']['error'] === UPLOAD_ERR_OK) {
        $archivo    = $_FILES['archivo'];
        $ext        = strtolower(pathinfo($archivo['name'], PATHINFO_EXTENSION));
        if ($ext === 'pdf') {
            $uploadsDir   = __DIR__ . '/../uploads/';
            $nuevoNombre  = uniqid('cert_') . '.pdf';
            $destino      = $uploadsDir . $nuevoNombre;

            if (move_uploaded_file($archivo['tmp_name'], $destino)) {
                // Eliminar el archivo anterior si existe
                $antiguo = __DIR__ . '/../' . $ruta_archivo;
                if (is_file($antiguo)) {
                    unlink($antiguo);
                }
                $ruta_archivo = 'uploads/' . $nuevoNombre;
            }
        }
    }

    // Actualizar base de datos
    $update = $pdo->prepare("UPDATE certificados 
        SET cedula = ?, nombre_participante = ?, nombre_curso = ?, numero_registro = ?, fecha_realizacion = ?, archivo_certificado = ?
        WHERE id = ?");
    $update->execute([$cedula, $nombre, $curso, $registro, $fecha, $ruta_archivo, $id]);

    // Mostrar ventana emergente y redirigir
    echo "<script>
            alert('✅ Datos actualizados correctamente.');
            window.location.href = 'ver_certificados.php';
          </script>";
    exit();
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
  <meta charset="UTF-8">
  <title>Editar Certificado</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="bg-light">

<div class="container mt-5" style="max-width:700px;">
  <h3 class="mb-4">✏️ Editar Certificado</h3>

  <form method="POST" enctype="multipart/form-data" class="card p-4 shadow-sm">
    <div class="mb-3">
      <label for="cedula" class="form-label">Cédula del Participante</label>
      <input type="text" name="cedula" id="cedula" class="form-control" required
             value="<?= htmlspecialchars($certificado['cedula']) ?>">
    </div>
    <div class="mb-3">
      <label for="nombre_participante" class="form-label">Nombre del Participante</label>
      <input type="text" name="nombre_participante" id="nombre_participante" class="form-control" required
             value="<?= htmlspecialchars($certificado['nombre_participante']) ?>">
    </div>
    <div class="mb-3">
      <label for="nombre_curso" class="form-label">Nombre del Curso</label>
      <input type="text" name="nombre_curso" id="nombre_curso" class="form-control" required
             value="<?= htmlspecialchars($certificado['nombre_curso']) ?>">
    </div>
    <div class="mb-3">
      <label for="numero_registro" class="form-label">Número de Registro</label>
      <input type="text" name="numero_registro" id="numero_registro" class="form-control" required
             value="<?= htmlspecialchars($certificado['numero_registro']) ?>">
    </div>
    <div class="mb-3">
      <label for="fecha_realizacion" class="form-label">Fecha de Realización</label>
      <input type="date" name="fecha_realizacion" id="fecha_realizacion" class="form-control" required
             value="<?= htmlspecialchars($certificado['fecha_realizacion']) ?>">
    </div>
    <div class="mb-3">
      <label class="form-label">PDF Actual</label>
      <p>
        <a href="../<?= htmlspecialchars($certificado['archivo_certificado']) ?>" target="_blank">Ver certificado actual</a>
      </p>
    </div>
    <div class="mb-3">
      <label for="archivo" class="form-label">Subir Nuevo PDF (opcional)</label>
      <input type="file" name="archivo" id="archivo" class="form-control" accept="application/pdf">
      <small class="text-muted">Si no subes un PDF, se mantiene el anterior.</small>
    </div>
    <button type="submit" class="btn btn-primary w-100">💾 Guardar Cambios</button>
    <a href="ver_certificados.php" class="btn btn-link mt-2">← Cancelar</a>
  </form>
</div>

</body>
</html>



