<?php
// login.php: Login del administrador

session_start();
require_once('../db.php'); // Asegurarse de usar require_once para evitar duplicaciones

// Si ya está logueado, redirigir al panel
if (isset($_SESSION['usuario'])) {
    header('Location: dashboard.php');
    exit();
}

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $usuario = trim($_POST['username']);
    $password = $_POST['password'];

    $stmt = $pdo->prepare("SELECT * FROM usuarios_admin WHERE username = :username");
    $stmt->execute([':username' => $usuario]);
    $usuario_db = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($usuario_db && password_verify($password, $usuario_db['password_hash'])) {
        $_SESSION['usuario'] = $usuario_db['username'];
        header('Location: dashboard.php');
        exit();
    } else {
        $error = "❌ Usuario o contraseña incorrectos.";
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Acceso Administrativo</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background: #f8fafc;
            display: flex;
            align-items: center;
            justify-content: center;
            height: 100vh;
        }
        .card {
            width: 100%;
            max-width: 420px;
            padding: 2rem;
            border-radius: 1rem;
            box-shadow: 0 4px 15px rgba(0,0,0,0.1);
        }
        .logo {
            font-size: 1.8rem;
            font-weight: bold;
            color: #1e3a8a;
        }
    </style>
</head>
<body>

<div class="card">
    <div class="text-center mb-4">
        <div class="logo">🔐 Admin ESIBOC-Style</div>
        <small class="text-muted">Panel de acceso restringido</small>
    </div>

    <?php if (!empty($error)): ?>
        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
    <?php endif; ?>

    <form method="POST" action="login.php">
        <div class="mb-3">
            <label for="username" class="form-label">👤 Usuario</label>
            <input type="text" class="form-control" id="username" name="username" placeholder="Nombre de usuario" required autofocus>
        </div>
        <div class="mb-3">
            <label for="password" class="form-label">🔑 Contraseña</label>
            <input type="password" class="form-control" id="password" name="password" placeholder="••••••••" required>
        </div>
        <button type="submit" class="btn btn-primary w-100">Iniciar sesión</button>
    </form>
</div>

</body>
</html>

