<?php
session_start();
// Incluimos la conexión, subimos un nivel para llegar a db.php
require_once __DIR__ . '/../db.php';

// Si no hay sesión de administrador, lo mandamos al login
if (!isset($_SESSION['usuario'])) {
    header('Location: login.php');
    exit();
}

$mensaje = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Recogemos y saneamos inputs
    $cedula           = trim($_POST['cedula'] ?? '');
    $nombre_participante = trim($_POST['nombre_participante'] ?? ''); // Nuevo campo
    $nombre_curso     = trim($_POST['nombre_curso'] ?? '');
    $numero_registro  = trim($_POST['numero_registro'] ?? '');
    $fecha_realizacion = $_POST['fecha_realizacion'] ?? '';
    $archivo          = $_FILES['archivo'] ?? null;

    if ($cedula && $nombre_participante && $nombre_curso && $numero_registro && $fecha_realizacion && $archivo && $archivo['error'] === UPLOAD_ERR_OK) {
        // Ruta absoluta a la carpeta uploads
        $uploadsDir = __DIR__ . '/../uploads/';
        if (!is_dir($uploadsDir)) {
            mkdir($uploadsDir, 0777, true);
        }

        // Limpiar nombre del archivo
        $originalName = basename($archivo['name']);
        $safeName = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $originalName);
        $uniqueName = uniqid() . '_' . $safeName;
        $destPath = $uploadsDir . $uniqueName;

        if (move_uploaded_file($archivo['tmp_name'], $destPath)) {
            // Guardamos en la base usando PDO ($pdo viene de db.php)
            $rutaEnBD = 'uploads/' . $uniqueName;
            $stmt = $pdo->prepare(
                "INSERT INTO certificados 
                 (cedula, nombre_participante, nombre_curso, numero_registro, fecha_realizacion, archivo_certificado)
                 VALUES (:cedula, :np, :curso, :reg, :fecha, :archivo)"
            );
            $stmt->execute([
                ':cedula'  => $cedula,
                ':np'      => $nombre_participante,   // Guardamos el nombre del participante
                ':curso'   => $nombre_curso,
                ':reg'     => $numero_registro,
                ':fecha'   => $fecha_realizacion,
                ':archivo' => $rutaEnBD
            ]);

            $mensaje = "<div class='alert alert-success'>✅ Certificado subido correctamente.</div>";
        } else {
            $mensaje = "<div class='alert alert-danger'>❌ Error al mover el archivo.</div>";
        }
    } else {
        $mensaje = "<div class='alert alert-warning'>⚠️ Todos los campos y el PDF son obligatorios.</div>";
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
  <meta charset="UTF-8">
  <title>Subir Certificado</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="bg-light">
  <div class="container mt-5" style="max-width:700px;">
    <h2 class="mb-4 text-center">📤 Subir Certificado</h2>
    <?= $mensaje ?>

    <form method="post" enctype="multipart/form-data" class="card p-4 shadow-sm">
      <div class="mb-3">
        <label for="cedula" class="form-label">Cédula del Participante</label>
        <input type="text" name="cedula" id="cedula" class="form-control" required>
      </div>
      <div class="mb-3">
        <label for="nombre_participante" class="form-label">Nombre del Participante</label>
        <input type="text" name="nombre_participante" id="nombre_participante" class="form-control" required>
      </div>
      <div class="mb-3">
        <label for="nombre_curso" class="form-label">Nombre del Curso</label>
        <input type="text" name="nombre_curso" id="nombre_curso" class="form-control" required>
      </div>
      <div class="mb-3">
        <label for="numero_registro" class="form-label">Número de Registro</label>
        <input type="text" name="numero_registro" id="numero_registro" class="form-control" required>
      </div>
      <div class="mb-3">
        <label for="fecha_realizacion" class="form-label">Fecha de Realización</label>
        <input type="date" name="fecha_realizacion" id="fecha_realizacion" class="form-control" required>
      </div>
      <div class="mb-3">
        <label for="archivo" class="form-label">Archivo PDF</label>
        <input type="file" name="archivo" id="archivo" class="form-control" accept="application/pdf" required>
      </div>
      <button type="submit" class="btn btn-primary w-100">Subir Certificado</button>
      <a href="dashboard.php" class="btn btn-link mt-2">← Volver al Panel</a>
    </form>
  </div>
</body>
</html>


