<?php
require_once __DIR__ . '/../db.php'; // Ruta correcta al archivo db.php

// Obtener los certificados desde la base de datos
$stmt = $pdo->query("SELECT * FROM certificados ORDER BY fecha_realizacion DESC");
$certificados = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ver Certificados - Admin</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background: #f8f9fa;
        }
        .table-hover tbody tr:hover {
            background-color: #f1f1f1;
        }
        .navbar {
            background-color: #343a40;
        }
        .navbar-brand, .navbar-nav .nav-link {
            color: #ffffff;
        }
        .card {
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
            border-radius: 8px;
        }
        .btn-outline-primary {
            border-radius: 50px;
        }
        .breadcrumb-item + .breadcrumb-item::before {
            content: "›";
        }
    </style>
</head>
<body>

<!-- Navbar -->
<nav class="navbar navbar-expand-lg navbar-dark">
    <div class="container">
        <a class="navbar-brand" href="dashboard.php">🔐 Panel Administrador</a>
    </div>
</nav>

<div class="container my-5">

    <!-- Breadcrumb -->
    <nav aria-label="breadcrumb">
        <ol class="breadcrumb bg-white p-2 rounded">
            <li class="breadcrumb-item"><a href="dashboard.php">Dashboard</a></li>
            <li class="breadcrumb-item active" aria-current="page">Ver Certificados</li>
        </ol>
    </nav>

    <!-- Título de la página -->
    <div class="row mb-4">
        <div class="col-12">
            <h3 class="text-center">Lista de Certificados</h3>
        </div>
    </div>

    <!-- Tabla de Certificados -->
    <div class="card">
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-striped table-bordered table-hover align-middle">
                    <thead class="table-light">
                        <tr>
                            <th>Participante</th>
                            <th>Cédula</th>
                            <th>Curso</th>
                            <th>Registro</th>
                            <th>Fecha de Realización</th>
                            <th class="text-center">Archivo</th>
                            <th class="text-center">Acciones</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($certificados as $certificado): ?>
                            <tr>
                                <td><?= htmlspecialchars($certificado['nombre_participante']) ?></td>
                                <td><?= htmlspecialchars($certificado['cedula']) ?></td>
                                <td><?= htmlspecialchars($certificado['nombre_curso']) ?></td>
                                <td><?= htmlspecialchars($certificado['numero_registro']) ?></td>
                                <td><?= date('d/m/Y', strtotime($certificado['fecha_realizacion'])) ?></td>
                                <td class="text-center">
                                    <?php
                                    $archivoRuta = __DIR__ . '/../' . $certificado['archivo_certificado'];
                                    if (file_exists($archivoRuta)): ?>
                                        <a href="<?= $certificado['archivo_certificado'] ?>" class="btn btn-outline-primary btn-sm" download>
                                            Descargar
                                        </a>
                                    <?php else: ?>
                                        <span class="text-muted">Archivo no disponible</span>
                                    <?php endif; ?>
                                </td>
                                <td class="text-center">
                                    <div class="d-flex justify-content-center gap-2 flex-wrap">
                                        <a href="editar_certificado.php?id=<?= $certificado['id'] ?>" class="btn btn-warning btn-sm">Editar</a>
                                        <a href="eliminar_certificado.php?id=<?= $certificado['id'] ?>" class="btn btn-danger btn-sm" onclick="return confirm('¿Seguro que deseas eliminar este certificado?');">Eliminar</a>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Volver al Dashboard -->
    <div class="text-center mt-4">
        <a href="dashboard.php" class="btn btn-link">← Volver al Dashboard</a>
    </div>

</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>





