<?php
session_start();
include('../db.php'); // Conexión a la base de datos

// Verifica si el usuario ya está logueado (para que no cree administradores sin estar logueado)
if (!isset($_SESSION['usuario'])) {
    header('Location: login.php'); // Si no está logueado, redirigir a login
    exit();
}

// Manejo del formulario
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $username = $_POST['username'];
    $password = $_POST['password'];
    $nombre_completo = $_POST['nombre_completo'];

    // Validación simple
    if (empty($username) || empty($password) || empty($nombre_completo)) {
        $error = "Todos los campos son obligatorios.";
    } else {
        // Verificar si el nombre de usuario ya existe
        $sql = "SELECT * FROM usuarios_admin WHERE username = :username";
        $stmt = $pdo->prepare($sql);
        $stmt->execute(['username' => $username]);
        $usuario = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($usuario) {
            $error = "El nombre de usuario ya está en uso.";
        } else {
            // Hashear la contraseña
            $password_hash = password_hash($password, PASSWORD_DEFAULT);

            // Insertar el nuevo administrador
            $sql = "INSERT INTO usuarios_admin (username, password_hash, nombre_completo) 
                    VALUES (:username, :password_hash, :nombre_completo)";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([
                'username' => $username,
                'password_hash' => $password_hash,
                'nombre_completo' => $nombre_completo
            ]);

            $success = "Administrador creado exitosamente.";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crear Administrador</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-5">
        <h2>Crear Administrador</h2>

        <?php if (isset($error)) echo "<div class='alert alert-danger'>$error</div>"; ?>
        <?php if (isset($success)) echo "<div class='alert alert-success'>$success</div>"; ?>

        <form action="crear_admin.php" method="POST">
            <div class="form-group">
                <label for="username">Nombre de Usuario</label>
                <input type="text" class="form-control" id="username" name="username" required>
            </div>
            <div class="form-group">
                <label for="password">Contraseña</label>
                <input type="password" class="form-control" id="password" name="password" required>
            </div>
            <div class="form-group">
                <label for="nombre_completo">Nombre Completo</label>
                <input type="text" class="form-control" id="nombre_completo" name="nombre_completo" required>
            </div>
            <button type="submit" class="btn btn-primary">Crear Administrador</button>
        </form>
    </div>
</body>
</html>
