<?php
// registrar_admin.php: Formulario para registrar nuevos administradores

session_start();
if (!isset($_SESSION['usuario'])) {
    header('Location: login.php'); // Si no está logueado, redirigir a login
    exit();
}

include('../db.php'); // Incluir la conexión a la base de datos

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Validar los campos del formulario
    $username = $_POST['username'];
    $password = $_POST['password'];
    $password_confirm = $_POST['password_confirm'];
    $nombre_completo = $_POST['nombre_completo'];

    // Comprobar si las contraseñas coinciden
    if ($password !== $password_confirm) {
        $error = "Las contraseñas no coinciden.";
    } else {
        // Validar que el nombre de usuario no exista ya
        $sql = "SELECT * FROM usuarios_admin WHERE username = :username";
        $stmt = $pdo->prepare($sql);
        $stmt->execute(['username' => $username]);
        $usuario_existente = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($usuario_existente) {
            $error = "El nombre de usuario ya existe. Intenta con otro.";
        } else {
            // Hashear la contraseña antes de guardarla
            $password_hash = password_hash($password, PASSWORD_DEFAULT);

            // Insertar el nuevo administrador en la base de datos
            $sql = "INSERT INTO usuarios_admin (username, password_hash, nombre_completo) 
                    VALUES (:username, :password_hash, :nombre_completo)";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([
                'username' => $username,
                'password_hash' => $password_hash,
                'nombre_completo' => $nombre_completo
            ]);

            $mensaje = "Administrador registrado exitosamente.";
        }
    }
}

?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrar Administrador</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-5">
        <h2>Registrar Nuevo Administrador</h2>

        <?php if (isset($mensaje)) echo "<div class='alert alert-success'>$mensaje</div>"; ?>
        <?php if (isset($error)) echo "<div class='alert alert-danger'>$error</div>"; ?>

        <form action="registrar_admin.php" method="POST">
            <div class="form-group">
                <label for="username">Nombre de Usuario</label>
                <input type="text" class="form-control" id="username" name="username" required>
            </div>
            <div class="form-group">
                <label for="password">Contraseña</label>
                <input type="password" class="form-control" id="password" name="password" required>
            </div>
            <div class="form-group">
                <label for="password_confirm">Confirmar Contraseña</label>
                <input type="password" class="form-control" id="password_confirm" name="password_confirm" required>
            </div>
            <div class="form-group">
                <label for="nombre_completo">Nombre Completo</label>
                <input type="text" class="form-control" id="nombre_completo" name="nombre_completo" required>
            </div>
            <button type="submit" class="btn btn-primary">Registrar Administrador</button>
        </form>
    </div>
</body>
</html>
