<?php
require_once __DIR__ . '/db.php';

$cedula = $_GET['cedula'] ?? '';
$mensaje = '';
$certificados = [];

if ($cedula !== '') {
    if (!preg_match('/^\d{5,15}$/', $cedula)) {
        $mensaje = '<div class="alert alert-danger" role="alert">❌ Cédula inválida. Debe contener entre 5 y 15 dígitos.</div>';
    } else {
        $stmt = $pdo->prepare("SELECT nombre_participante, nombre_curso, numero_registro, fecha_realizacion, archivo_certificado 
                               FROM certificados WHERE cedula = :cedula ORDER BY fecha_realizacion DESC");
        $stmt->execute([':cedula' => $cedula]);
        $certificados = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (empty($certificados)) {
            $mensaje = '<div class="alert alert-warning" role="alert">⚠️ No se encontraron certificados para la cédula <strong>' . htmlspecialchars($cedula) . '</strong>.</div>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Consulta de Certificados</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
  <style>
    body { background-color: #f0f2f5; }
    .navbar { background: #0d6efd; }
    .navbar-brand, .nav-link { color: #fff !important; }
    .card { border-radius: 1rem; box-shadow: 0 0.25rem 1rem rgba(0,0,0,0.05); }
    .table th, .table td { vertical-align: middle; }
    .badge-pdf { font-size: 0.95rem; padding: 0.4em 0.7em; }
  </style>
</head>
<body>

<nav class="navbar navbar-expand-lg mb-4">
  <div class="container">
    <a class="navbar-brand" href="index.php">🎓 Consulta de Certificados</a>
  </div>
</nav>

<div class="container">
  <!-- Mensaje -->
  <?= $mensaje ?>

  <!-- Formulario -->
  <div class="card mb-4">
    <div class="card-body">
      <form class="row g-3 align-items-end" method="get" action="resultado.php">
        <div class="col-md-9">
          <label for="cedula" class="form-label">Número de Cédula</label>
          <input type="text" class="form-control" id="cedula" name="cedula"
                 value="<?= htmlspecialchars($cedula) ?>" placeholder="Ej: 123456789" required pattern="\d{5,15}">
        </div>
        <div class="col-md-3 d-grid">
          <button type="submit" class="btn btn-primary">🔍 Buscar</button>
        </div>
      </form>
    </div>
  </div>

  <!-- Resultados -->
  <?php if ($certificados): ?>
    <div class="card">
      <div class="card-body">
        <h5 class="card-title mb-3">Certificados encontrados para la cédula <strong><?= htmlspecialchars($cedula) ?></strong></h5>
        <div class="table-responsive">
          <table class="table table-bordered table-hover">
            <thead class="table-light">
              <tr>
                <th>Participante</th>
                <th>Curso</th>
                <th>N° Registro</th>
                <th>Fecha</th>
                <th class="text-center">Archivo</th>
              </tr>
            </thead>
            <tbody>
              <?php foreach ($certificados as $c): ?>
                <tr>
                  <td><?= htmlspecialchars($c['nombre_participante']) ?></td>
                  <td><?= htmlspecialchars($c['nombre_curso']) ?></td>
                  <td><?= htmlspecialchars($c['numero_registro']) ?></td>
                  <td><?= date('d/m/Y', strtotime($c['fecha_realizacion'])) ?></td>
                  <td class="text-center">
                    <a href="<?= htmlspecialchars($c['archivo_certificado']) ?>" target="_blank" download class="btn btn-outline-success btn-sm">
                      📄 Descargar PDF
                    </a>
                  </td>
                </tr>
              <?php endforeach; ?>
            </tbody>
          </table>
        </div>
      </div>
    </div>
  <?php endif; ?>

  <div class="text-center mt-4">
    <a href="index.php" class="btn btn-outline-secondary">← Nueva Consulta</a>
  </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>


